@@ -37,13 +37,18 @@ def get_status(t):
         msg = term.black
     elif t["status"] == "running":
         msg = term.blue
+    elif t["status"] == "terminating":
+        if t["message"] == "completed":
+            msg = term.orange
+        else:
+            msg = term.red
     elif t["status"] == "stopped":
         if t["message"] == "completed":
             msg = term.green
         else:
             msg = term.red
     msg += t["status"]
-    if "message" in t:
+    if t.get("message"):
         msg += ":" + t["message"]
     msg += term.normal
     return msg
@@ -56,7 +61,9 @@ def argparse_define():
     parser.add_argument('-l', '--log-level', default='INFO',
                         help="log-level (INFO|WARN|DEBUG|FATAL|ERROR)")
     parser.add_argument('-s', '--service', help="service name")
+    parser.add_argument('-P', '--priority', type=int, default=0, help='task priority - highest better')
     parser.add_argument('-m', '--model', help='model')
+    parser.add_argument('-c', '--config', help="configuration file (for `set` only)")
     parser.add_argument('-e', '--entity_owner', help='entity owner')
     parser.add_argument('-i', '--docker_image',
                               default=os.getenv('LAUNCHER_IMAGE', None),
@@ -208,11 +215,15 @@ def execute(args, auth):
         args_launch += ["-s", args.service]
         if args.entity_owner:
             args_launch += ["-e", args.entity_owner]
+        args_launch += ["-P", str(args.priority)]
         if args.docker_image:
             args_launch += ["-i", args.docker_image, "--upgrade", "none"]
         args_launch += ["--novalidschema"]
         args_launch += ["--", "-m", args.model]
-        args_launch += ["-c", '{"postprocess":{"remove_placeholders":true}}']
+        if args.config:
+            args_launch += ["-c", args.config]
+        else:
+            args_launch += ["-c", '{"postprocess":{"remove_placeholders":true}}']
         args_launch += ["--config_update_mode", "merge"]
         args_launch += ["trans", "-i", tmp_file]
         args_launch += ["-o", "launcher:"+output_path]
@@ -260,7 +271,10 @@ def execute(args, auth):
                 if task[0] is None or task[1] is False:
                     continue
                 task_id = task[0]
-                r = requests.get(os.path.join(args.url, "task/status", task[0]), auth=auth)
+                fields_list = ["content", "status", "message", "files", "queued_time", "allocated_time", "running_time",
+                               "terminating_time", "stopped_time"]
+                params = {"fields": ",".join(fields_list)}
+                r = requests.get(os.path.join(args.url, "task/status", task[0]), auth=auth, params=params)
                 if r.status_code != 200:
                     logger.error('[%s] failed \'task/status\' service: %s', task[0], r.text)
                     sys.exit(1)
@@ -272,7 +286,7 @@ def execute(args, auth):
                         continue
                 times = []
                 for k in t:
-                    if k.endswith('_time'):
+                    if k.endswith('_time') and t.get(k):
                         times.append(k)
                 sorted_times = sorted(times, key=lambda k: float(t[k]))
                 last = -1
@@ -288,10 +302,10 @@ def execute(args, auth):
                         current = float(t[k])
                         delta = current - last if last != -1 else 0
                         last = current
-                        if last_k == "queued_time" or last_k == "running_time":
+                        if last_k in ["queued_time", "allocated_time", "running_time", "terminating_time"]:
                             tmsg = last_k[:-5]+" for %ds" % delta
                         last_k = k
-                if t["status"] == 'running' or t["status"] == "queued":
+                if t["status"] in ["queued", "allocated", "running", "terminating"]:
                     running = True
                 elif t["status"] == 'stopped':
                     task[0] = None
